summaryrefslogtreecommitdiff
path: root/gnu/usr.bin/perl/Porting
diff options
context:
space:
mode:
authorTodd C. Miller <millert@cvs.openbsd.org>2004-08-09 17:48:49 +0000
committerTodd C. Miller <millert@cvs.openbsd.org>2004-08-09 17:48:49 +0000
commit069768bdb70fb3052599d3e70898a0ed0e1c31d2 (patch)
tree1492d59179e2c9b07cb6c6754f78a3ef6e608e68 /gnu/usr.bin/perl/Porting
parentf2ebe24544ebe30f7ed499fda280dce09361f966 (diff)
Import of stock perl 5.8.5
Diffstat (limited to 'gnu/usr.bin/perl/Porting')
-rw-r--r--gnu/usr.bin/perl/Porting/checkcase.pl26
-rw-r--r--gnu/usr.bin/perl/Porting/config.sh49
-rw-r--r--gnu/usr.bin/perl/Porting/corecpan.pl69
3 files changed, 119 insertions, 25 deletions
diff --git a/gnu/usr.bin/perl/Porting/checkcase.pl b/gnu/usr.bin/perl/Porting/checkcase.pl
new file mode 100644
index 00000000000..66dccd24c88
--- /dev/null
+++ b/gnu/usr.bin/perl/Porting/checkcase.pl
@@ -0,0 +1,26 @@
+#!/usr/bin/perl
+# Finds the files that have the same name, case insensitively,
+# in the current directory and its subdirectories
+
+use warnings;
+use strict;
+use File::Find;
+
+my %files;
+find(sub {
+ my $name = $File::Find::name;
+ # Assumes that the path separator is exactly one character.
+ $name =~ s/^\.\..//;
+ push @{$files{lc $name}}, $name;
+ }, '.');
+
+my $failed;
+
+foreach (values %files) {
+ if (@$_ > 1) {
+ print join(", ", @$_), "\n";
+ $failed++;
+ }
+}
+
+print "no similarly named files found\n" unless $failed;
diff --git a/gnu/usr.bin/perl/Porting/corecpan.pl b/gnu/usr.bin/perl/Porting/corecpan.pl
new file mode 100644
index 00000000000..48fb7d92bac
--- /dev/null
+++ b/gnu/usr.bin/perl/Porting/corecpan.pl
@@ -0,0 +1,69 @@
+#!perl
+# Reports, in a perl source tree, which dual-lived core modules have not the
+# same version than the corresponding module on CPAN.
+
+use 5.9.0;
+use strict;
+use Getopt::Std;
+use ExtUtils::MM_Unix;
+use lib 'Porting';
+use Maintainers qw(get_module_files %Modules);
+
+our $packagefile = '02packages.details.txt';
+
+sub usage () {
+ die <<USAGE;
+$0 - report which core modules are outdated.
+To be run at the root of a perl source tree.
+Options :
+-h : help
+-v : verbose (print all versions of all files, not only those which differ)
+-f : force download of $packagefile from CPAN
+ (it's expected to be found in the current directory)
+USAGE
+}
+
+sub get_package_details () {
+ my $url = 'http://www.cpan.org/modules/02packages.details.txt.gz';
+ unlink $packagefile;
+ system("wget $url && gunzip $packagefile.gz") == 0
+ or die "Failed to get package details\n";
+}
+
+getopts('fhv');
+our $opt_h and usage;
+our $opt_f or !-f $packagefile and get_package_details;
+
+# Load the package details. All of them.
+my %cpanversions;
+open my $fh, $packagefile or die $!;
+while (<$fh>) {
+ my ($p, $v) = split ' ';
+ $cpanversions{$p} = $v;
+}
+close $fh;
+
+for my $dist (sort keys %Modules) {
+ next unless $Modules{$dist}{CPAN};
+ print "Module $dist...\n";
+ for my $file (get_module_files($dist)) {
+ next if $file !~ /\.pm\z/ or $file =~ m{^t/};
+ my $vcore = MM->parse_version($file) // 'undef';
+ my $module = $file;
+ $module =~ s/\.pm\z//;
+ # some heuristics to figure out the module name from the file name
+ $module =~ s{^(lib|ext)/}{}
+ and $1 eq 'ext'
+ and ( $module =~ s{^(.*)/lib/\1\b}{$1},
+ $module =~ s{(\w+)/\1\b}{$1},
+ $module =~ s{^Encode/encoding}{encoding},
+ $module =~ s{^MIME/Base64/QuotedPrint}{MIME/QuotedPrint},
+ $module =~ s{^List/Util/lib/Scalar}{Scalar},
+ );
+ $module =~ s{/}{::}g;
+ my $vcpan = $cpanversions{$module} // 'not found';
+ if (our $opt_v or $vcore ne $vcpan) {
+ print " $file: core=$vcore, cpan=$vcpan\n";
+ }
+ }
+}
diff --git a/gnu/usr.bin/perl/Porting/config.sh b/gnu/usr.bin/perl/Porting/config.sh
index c621cc2b3e6..07ca782f518 100644
--- a/gnu/usr.bin/perl/Porting/config.sh
+++ b/gnu/usr.bin/perl/Porting/config.sh
@@ -8,8 +8,8 @@
# Package name : perl5
# Source directory : .
# Configuration time: Wed Jan 14 16:41:27 GMT 2004
# Configured by : nick
# Target system : linux bagpuss.unfortu.net 2.4.19-rmk4 #3 fri oct 25 21:57:55 bst 2002 armv4l unknown
Author=''
@@ -36,8 +36,8 @@ api_subversion='0'
api_version='8'
api_versionstring='5.8.0'
ar='ar'
-archlib='/opt/perl/lib/5.8.3/armv4l-linux'
-archlibexp='/opt/perl/lib/5.8.3/armv4l-linux'
+archlib='/opt/perl/lib/5.8.5/armv4l-linux'
+archlibexp='/opt/perl/lib/5.8.5/armv4l-linux'
archname64=''
archname='armv4l-linux'
archobjs=''
@@ -55,15 +55,15 @@ castflags='0'
cat='cat'
cc='cc'
cccdlflags='-fpic'
-ccdlflags='-rdynamic'
-ccflags='-fno-strict-aliasing -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
+ccdlflags='-Wl,-E'
+ccflags='-fno-strict-aliasing -pipe -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
ccflags_uselargefiles='-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
ccname='gcc'
ccsymbols='__APCS_32__=1 __ARM_ARCH_3__=1 __CHAR_UNSIGNED__=1 __GNUC_MINOR__=95 __arm__=1 __linux=1 __linux__=1 __unix=1 __unix__=1 cpu=arm machine=arm system=posix system=unix'
ccversion=''
-cf_by='nick'
+cf_by='yourname'
cf_email='yourname@yourhost.yourplace.com'
-cf_time='Wed Jan 14 16:41:27 GMT 2004'
+cf_time='Fri Jul 16 20:59:18 BST 2004'
charsize='1'
chgrp=''
chmod='chmod'
@@ -77,7 +77,7 @@ cpio=''
cpp='cpp'
cpp_stuff='42'
cppccsymbols='__ELF__=1 __GNUC__=2 linux=1 unix=1'
-cppflags='-fno-strict-aliasing -I/usr/local/include'
+cppflags='-fno-strict-aliasing -pipe -I/usr/local/include'
cpplast='-'
cppminus='-'
cpprun='cc -E'
@@ -668,7 +668,7 @@ inc_version_list=' '
inc_version_list_init='0'
incpath=''
inews=''
-installarchlib='/opt/perl/lib/5.8.3/armv4l-linux'
+installarchlib='/opt/perl/lib/5.8.5/armv4l-linux'
installbin='/opt/perl/bin'
installhtml1dir=''
installhtml3dir=''
@@ -676,13 +676,13 @@ installman1dir='/opt/perl/man/man1'
installman3dir='/opt/perl/man/man3'
installprefix='/opt/perl'
installprefixexp='/opt/perl'
-installprivlib='/opt/perl/lib/5.8.3'
+installprivlib='/opt/perl/lib/5.8.5'
installscript='/opt/perl/bin'
-installsitearch='/opt/perl/lib/site_perl/5.8.3/armv4l-linux'
+installsitearch='/opt/perl/lib/site_perl/5.8.5/armv4l-linux'
installsitebin='/opt/perl/bin'
installsitehtml1dir=''
installsitehtml3dir=''
-installsitelib='/opt/perl/lib/site_perl/5.8.3'
+installsitelib='/opt/perl/lib/site_perl/5.8.5'
installsiteman1dir='/opt/perl/man/man1'
installsiteman3dir='/opt/perl/man/man3'
installsitescript='/opt/perl/bin'
@@ -804,13 +804,12 @@ pg='pg'
phostname=''
pidtype='pid_t'
plibpth=''
-pm_apiversion='5.005'
pmake=''
pr=''
prefix='/opt/perl'
prefixexp='/opt/perl'
-privlib='/opt/perl/lib/5.8.3'
-privlibexp='/opt/perl/lib/5.8.3'
+privlib='/opt/perl/lib/5.8.5'
+privlibexp='/opt/perl/lib/5.8.5'
procselfexe='"/proc/self/exe"'
prototype='define'
ptrsize='4'
@@ -871,17 +870,17 @@ sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 6, 17, 29, 31, 0'
sig_size='68'
signal_t='void'
-sitearch='/opt/perl/lib/site_perl/5.8.3/armv4l-linux'
-sitearchexp='/opt/perl/lib/site_perl/5.8.3/armv4l-linux'
+sitearch='/opt/perl/lib/site_perl/5.8.5/armv4l-linux'
+sitearchexp='/opt/perl/lib/site_perl/5.8.5/armv4l-linux'
sitebin='/opt/perl/bin'
sitebinexp='/opt/perl/bin'
sitehtml1dir=''
sitehtml1direxp=''
sitehtml3dir=''
sitehtml3direxp=''
-sitelib='/opt/perl/lib/site_perl/5.8.3'
+sitelib='/opt/perl/lib/site_perl/5.8.5'
sitelib_stem='/opt/perl/lib/site_perl'
-sitelibexp='/opt/perl/lib/site_perl/5.8.3'
+sitelibexp='/opt/perl/lib/site_perl/5.8.5'
siteman1dir='/opt/perl/man/man1'
siteman1direxp='/opt/perl/man/man1'
siteman3dir='/opt/perl/man/man3'
@@ -918,7 +917,7 @@ stdio_stream_array=''
strerror_r_proto='0'
strings='/usr/include/string.h'
submit=''
-subversion='3'
+subversion='5'
sysman='/usr/share/man/man1'
tail=''
tar=''
@@ -959,6 +958,7 @@ usefaststdio='define'
useithreads='undef'
uselargefiles='define'
uselongdouble='undef'
+usemallocwrap='define'
usemorebits='undef'
usemultiplicity='undef'
usemymalloc='n'
@@ -1000,13 +1000,12 @@ vendorprefix=''
vendorprefixexp=''
vendorscript=''
vendorscriptexp=''
-version='5.8.3'
-version_patchlevel_string='version 8 subversion 3'
+version='5.8.5'
+version_patchlevel_string='version 8 subversion 5'
versiononly='undef'
vi=''
voidflags='15'
xlibpth='/usr/lib/386 /lib/386'
-xs_apiversion='5.8.3'
yacc='yacc'
yaccflags=''
zcat=''
@@ -1024,7 +1023,7 @@ config_arg6='-Dmyhostname=yourhost'
config_arg7='-dE'
PERL_REVISION=5
PERL_VERSION=8
-PERL_SUBVERSION=3
+PERL_SUBVERSION=5
PERL_API_REVISION=5
PERL_API_VERSION=8
PERL_API_SUBVERSION=0
@@ -8,8 +8,8 @@
# Package name : perl5
# Source directory : .
-# Configuration time: Wed Jan 14 16:41:27 GMT 2004
-# Configured by : nick
+# Configuration time: Fri Jul 16 20:59:18 BST 2004
+# Configured by : yourname
# Target system : linux bagpuss.unfortu.net 2.4.19-rmk4 #3 fri oct 25 21:57:55 bst 2002 armv4l unknown
Author=''